<?php
if( !class_exists('wordpressIDXAdminPageConfig')) {
	/**
	 * 
	 * This class has methods to support creating forms to set templates, custom url patterns and
	 * titles for WordpressIDX Virtual Pages.
	 * 
	 * @author wordpressIDX
	 */
	class wordpressIDXAdminPageConfig {
		private static $instance ;
		private $virtualPageFactory ;

		private function __construct(){
			$this->virtualPageFactory=wordpressIDXVirtualPageFactory::getInstance() ;
		}

		public static function getInstance(){
			if( !isset(self::$instance)){
				self::$instance = new wordpressIDXAdminPageConfig();
			}
			return self::$instance;
		}
		
		public function getDefaultPageSetup(){
			$selectedTemplate=wordpressIDXVirtualPageHelper::getInstance()->getDefaultTemplate() ;
			?>
			<h3>Other IDX Pages</h3>
			<table>
				<tr>
					<td><b>Theme Template*:</b></td>
					<td>
						<select name="<?php echo(wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_DEFAULT)?>">
							<option value='default'><?php _e('Default Template'); ?></option>
							<?php page_template_dropdown( $selectedTemplate ); ?>
						</select>
					</td>
				</tr>
			</table>
		<?php
		}

		public function permalinkJavascript( $permalinkId, $urlFactory ){
			?>
			<script>
				jQuery('#<?php echo($permalinkId)?>EditButton').click( function(){
					jQuery('#<?php echo($permalinkId)?>Edit').show();
					jQuery('#<?php echo($permalinkId)?>Container').hide();
				});
				jQuery('#<?php echo($permalinkId)?>DoneButton').click( function(){
					var inputObject=jQuery('#<?php echo($permalinkId)?>');
					var inputValue = inputObject.val();
					inputValue = inputValue.replace(/\s/g,"-");
					inputObject.val(inputValue);

					jQuery('#<?php echo($permalinkId)?>Text').text( jQuery('#<?php echo($permalinkId)?>').val() );
					jQuery('#<?php echo($permalinkId)?>Container').show();
					jQuery('#<?php echo($permalinkId)?>Edit').hide();
				});
			</script>
			<?php
		}

		/**
		 * We do not use getPageSetup to display the detail page customization, because we require some 
		 * extra explanation of the permalink structure for detail pages.
		 * Otherwisse, this function is similar to getPageSetup.
		 */
		public function getDetailPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Property Details",
				wordpressIDXVirtualPageFactory::LISTING_DETAIL, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_DETAIL, 
				$urlFactory->getListingDetailUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_DETAIL,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_DETAIL,
				"(If empty, the property address will be the title)",
				"%ADDRESS%/%LISTING_NUMBER%/%LISTING_PROVIDER%"	); 			
		}
		
		/**
		 * We do not use getPageSetup to display the detail page customization, because we require some 
		 * extra explanation of the permalink structure for detail pages.
		 * Otherwisse, this function is similar to getPageSetup.
		 */
		public function getSoldDetailPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Sold Property Details",
				wordpressIDXVirtualPageFactory::LISTING_SOLD_DETAIL, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_SOLD_DETAIL, 
				$urlFactory->getListingSoldDetailUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_SOLD_DETAIL,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_SOLD_DETAIL,
				"(If empty, the property address will be the title)",
				"%ADDRESS%/%LISTING_NUMBER%/%LISTING_PROVIDER%"	); 			
		}		

		public function getSearchPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup("Search Form", wordpressIDXVirtualPageFactory::LISTING_SEARCH_FORM, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_SEARCH,
				$urlFactory->getListingsSearchFormUrl(false), 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_SEARCH, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_SEARCH);		
							
			$virtualPage = $this->virtualPageFactory->getVirtualPage( wordpressIDXVirtualPageFactory::LISTING_SEARCH_FORM );
			$permalinkId=wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_SEARCH ;
		}
		
		public function getMapSearchPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup("Map Search", wordpressIDXVirtualPageFactory::MAP_SEARCH_FORM, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_MAP_SEARCH,
				$urlFactory->getMapSearchFormUrl(false), 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_MAP_SEARCH, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_MAP_SEARCH);		
							
			$virtualPage = $this->virtualPageFactory->getVirtualPage( wordpressIDXVirtualPageFactory::MAP_SEARCH_FORM );
			$permalinkId=wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_MAP_SEARCH ;
		}		

		public function getAdvSearchPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup("Advanced Search Form", wordpressIDXVirtualPageFactory::LISTING_ADVANCED_SEARCH_FORM, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_ADV_SEARCH, 
				$urlFactory->getListingsAdvancedSearchFormUrl(false), 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_ADV_SEARCH, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_ADV_SEARCH);		
		}

		public function getOrganizerLoginPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup("Organizer Login", wordpressIDXVirtualPageFactory::ORGANIZER_LOGIN, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_ORG_LOGIN, 
				$urlFactory->getOrganizerLoginUrl(false), 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_ORG_LOGIN, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_ORG_LOGIN);						
		}

		public function getEmailAlertsPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup("Email Alerts", wordpressIDXVirtualPageFactory::ORGANIZER_EDIT_SAVED_SEARCH, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_EMAIL_UPDATES, 
				$urlFactory->getOrganizerEditSavedSearchUrl(false), 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_EMAIL_UPDATES, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_EMAIL_UPDATES);							
		}

		public function getFeaturedPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup("Featured Properties", wordpressIDXVirtualPageFactory::FEATURED_SEARCH, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_FEATURED, 
				$urlFactory->getFeaturedSearchResultsUrl(false), 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_FEATURED, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_FEATURED);
		}		
		
		public function getContactFormPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Contact Form",
				wordpressIDXVirtualPageFactory::CONTACT_FORM, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_CONTACT_FORM, 
				$urlFactory->getContactFormUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_CONTACT_FORM,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_CONTACT_FORM	);		
		}	
		
		public function getValuationFormPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Valuation Request",
				wordpressIDXVirtualPageFactory::VALUATION_FORM, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_VALUATION_FORM, 
				$urlFactory->getValuationFormUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_VALUATION_FORM,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_VALUATION_FORM	); 				
		}
		
		public function getSupplementalListingPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Supplemental Listing",
				wordpressIDXVirtualPageFactory::SUPPLEMENTAL_LISTING, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_SUPPLEMENTAL_LISTING, 
				$urlFactory->getSupplementalListingUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_SUPPLEMENTAL_LISTING,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_SUPPLEMENTAL_LISTING	); 			
		}
		
		public function getSoldFeaturedListingPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Sold Featured Listing",
				wordpressIDXVirtualPageFactory::SOLD_FEATURED_LISTING, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_SOLD_FEATURED, 
				$urlFactory->getSoldFeaturedListingUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_SOLD_FEATURED,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_SOLD_FEATURED	); 			
		}
		
		public function getOpenHomeSearchFormPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Open Home Search",
				wordpressIDXVirtualPageFactory::OPEN_HOME_SEARCH_FORM, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_OPEN_HOME_SEARCH_FORM, 
				$urlFactory->getOpenHomeSearchFormUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_OPEN_HOME_SEARCH_FORM,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_OPEN_HOME_SEARCH_FORM	); 				
		}
		
		public function getOfficeListPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Office List",
				wordpressIDXVirtualPageFactory::OFFICE_LIST, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_OFFICE_LIST, 
				$urlFactory->getOfficeListUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_OFFICE_LIST,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_OFFICE_LIST	); 				
		}	

		public function getOfficeDetailPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Office Detail",
				wordpressIDXVirtualPageFactory::OFFICE_DETAIL, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_OFFICE_DETAIL, 
				$urlFactory->getOfficeDetailUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_OFFICE_DETAIL,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_OFFICE_DETAIL,
				"(If the title is blank, the office name will be used for the title)",
				"%OFFICE_NAME%/%OFFICE_ID%"	); 				
		}			
		public function getAgentListPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Agent List",
				wordpressIDXVirtualPageFactory::AGENT_LIST, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_AGENT_LIST, 
				$urlFactory->getAgentListUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_AGENT_LIST,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_AGENT_LIST	); 				
		}	

		public function getAgentDetailPageSetup(){
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$this->getPageSetup( "Agent Bio",
				wordpressIDXVirtualPageFactory::AGENT_DETAIL, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_AGENT_DETAIL, 
				$urlFactory->getAgentDetailUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_AGENT_DETAIL,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_AGENT_DETAIL,
				"(If the title is blank, the agent name will be used for the title)",
				"%AGENT_NAME%/%AGENT_ID%"	); 				
		}			
		
		/**
		 * 
		 * Function to setup form elements to allow customization of WordpressIDX page title, urls and 
		 * display templates.  WordpressIDX pages are not true pages in the Wordpress database, so we 
		 * need to remember the title, permalink and template as options.
		 * 
		 * @param unknown_type $pageTitle
		 * @param unknown_type $virtualPageKey
		 * @param unknown_type $permalLinkId
		 * @param unknown_type $currentUrl
		 * @param unknown_type $titleOption
		 * @param unknown_type $templateOption
		 */
		public function getPageSetup($pageTitle, $virtualPageKey, $permalinkId, $currentUrl, $titleOption, 
			$templateOption, $extraTitleText=null, $extraPermalinkText=null ) {
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			$virtualPage = $this->virtualPageFactory->getVirtualPage( $virtualPageKey  );
		?>

			<h3><?php echo($pageTitle)?></h3>
			<table>
				<tr>
					<td><b>Permalink:</b></td>
					<td>
					  <div id="<?php echo($permalinkId)?>Container">
					  	<?php echo $urlFactory->getBaseUrl()?>/<span id="<?php echo($permalinkId)?>Text"><?php echo $currentUrl?></span>/<?php if($extraPermalinkText != null){echo($extraPermalinkText);}?>
					  	<input id="<?php echo($permalinkId)?>EditButton" type="button" value="Edit">
					  	
					  </div>
					  <div id="<?php echo($permalinkId)?>Edit" style="display: none;" >
						<?php echo $urlFactory->getBaseUrl()?>/
						<input size="40"
							type="text"
							id="<?php echo($permalinkId)?>"
							name="<?php echo($permalinkId)?>"
							value="<?php echo $currentUrl?>" />/<?php if($extraPermalinkText != null){echo($extraPermalinkText);}?>
						<input id="<?php echo($permalinkId)?>DoneButton" type="button" value="Done">
					  </div>
					</td>
				</tr>
				<tr>
					<td><b>Title:</b></td>
					<td>
						<input type="text" name="<?php echo($titleOption)?>" value="<?php echo($virtualPage->getTitle())?>" />
						<?php if($extraTitleText != null){echo($extraTitleText);}?>
					</td>
				</tr>
				<tr>
					<td><b>Theme Template*:</b></td>
					<td>
						<select name="<?php echo($templateOption)?>">
							<option value='default'><?php _e('Default Template'); ?></option>
							<?php page_template_dropdown($virtualPage->getPageTemplate()); ?>
						</select>
					</td>
				</tr>
			</table>

		<?php
			$this->permalinkJavascript( $permalinkId, $urlFactory );
		}		
			
		
		
		public function getHotsheetPageSetup(){			
			$urlFactory = wordpressIDXUrlFactory::getInstance() ;
			
			$virtualPage = $this->virtualPageFactory->getVirtualPage( wordpressIDXVirtualPageFactory::HOTSHEET_SEARCH_RESULTS );
			$permalinkId=wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_HOTSHEET . "-list";
			$hotsheetListVirtualPage = $this->virtualPageFactory->getVirtualPage( wordpressIDXVirtualPageFactory::HOTSHEET_LIST );
		?>
			<h3>Top Picks Index</h3>
			<table>
				<tr>
					<td><b>Permalink:</b></td>
					<td>
					  <div id="<?php echo($permalinkId)?>Container">
					  	<?php echo($urlFactory->getHotsheetListUrl(true))?>
					  </div>
					</td>
				</tr>
				<tr>
					<td><b>Title:</b></td>
					<td>
					  <?php echo($hotsheetListVirtualPage->getTitle())?>
					</td>
				</tr>
			</table>
			
		<?php
			$this->getPageSetup( "Top Picks",
				wordpressIDXVirtualPageFactory::HOTSHEET_SEARCH_RESULTS, 
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_PERMALINK_TEXT_HOTSHEET, 
				$urlFactory->getHotsheetSearchResultsUrl(false),
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TITLE_HOTSHEET,
				wordpressIDXVirtualPageHelper::OPTION_VIRTUAL_PAGE_TEMPLATE_HOTSHEET,
				"(If empty, the name of the Top Picks list will be the title)",
				"%TOPPICKS_NAME%/%TOPPICKS_ID%"	);	
		}
	}
}
?>